==> liveness-1.0.1.tar.gz: liveness/README.md <==
# Liveness Module

## Description
The Liveness module monitors the availability of different environments and provides notifications and logs about outages and recovery events.

## Requirements
- Drupal 10 or 11
- Drush

## Installation
1. Place the module in the `modules/custom` directory.
2. Enable the module: `drush en liveness`
3. Configure the module settings at `/admin/config/development/performance/liveness`.

## Configuration
- Set the URLs for the environments and enable/disable probing.
- Enter email addresses for notifications.

## Drush Commands
- `drush liveness:check http://example.com example-environment` - Check the liveness of configured environments and merge logs.

## a php command external to drupal has been provided which wraps the drush command and provides event notification logging even if drupal db is down
## Usage
- `php liveness.php /path/to/drupal http://url environment-name`
- `php liveness.php /var/www/html/ http://example.com example`


## Crontab Setup
Add a crontab entry to invoke Drupal cron and Drush liveness check periodically.

- `crontab -e`
- add lines to crontab:
- `#MIN HOUR DOM MONTH DOW CMD`
- `1 * * * * php /path/to/drupal/html/modules/contrib/liveness/liveness.php http://example.com environment-name;`
- `2 * * * * php /path/to/drupal/html/modules/contrib/liveness/liveness.php http://example2.com environment-name2;`
- `3 * * * * php /path/to/drupal/html/modules/contrib/liveness/liveness.php http://example3.com environment-name3;`

==> liveness-1.0.2.tar.gz: liveness/README.md <==
# Liveness Module

## Description
The Liveness module monitors environment availability, logging outages and 
recoveries.
## Requirements
- Drupal 10 or 11
- Drush

## Installation
1. Place the module in the `modules/contrib` directory.
2. Enable the module: `drush en liveness`
3. Configure the module settings at `/admin/config/development/performance/liveness`.

## Configuration
- Set the URLs for the environments and enable/disable probing.
- Enter email addresses for notifications.

## A php command which wraps the drush command and provides event notification logging even if drupal db is down
## Usage
- `php /path/to/drupal/html/modules/contrib/liveness/liveness.php /path/to/drupal http://url environment-name`
- `php /path/to/drupal/html/modules/contrib/liveness/liveness.php /var/www/html/ http://example.com example`

## Crontab Setup
Add a crontab entry to invoke Drupal cron and Drush liveness check periodically.

- `crontab -e`
- add lines to crontab:
- `#MIN HOUR DOM MONTH DOW CMD`
- `1 * * * * php /path/to/drupal/html/modules/contrib/liveness/liveness.php http://example.com environment-name;`
- `2 * * * * php /path/to/drupal/html/modules/contrib/liveness/liveness.php http://example2.com environment-name2;`
- `3 * * * * php /path/to/drupal/html/modules/contrib/liveness/liveness.php http://example3.com environment-name3;`


## Drush Commands - see the above php command instead of using this.
- `drush liveness:check http://example.com example-environment` - Check the liveness of configured environments and merge logs.
